package com.huimv.environment.service.impl;

import cn.hutool.core.date.DateTime;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.dynamic.datasource.annotation.DS;
import com.huimv.common.date.DateUtil;
import com.huimv.common.result.Result;
import com.huimv.common.result.ResultCode;
import com.huimv.environment.entity.*;
import com.huimv.environment.repo.*;
import com.huimv.environment.service.IEnvironmentControlService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.util.*;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Service
public class EnvironmentControlServiceImpl implements IEnvironmentControlService {
    @Autowired
    private BasePigpenRepo basePigpenRepo;
    @Autowired
    private BaseColumnPeriodRepo baseColumnPeriodRepo;
    @Autowired
    private SjHkAqRepo aqRepo;
    @Autowired
    private SjHkSdRepo sdRepo;
    @Autowired
    private SjHkWdRepo wdRepo;
    @Autowired
    private FarmSmRepository farmSmRepository;

    @Value("${minTemp}")
    private  Double minTemp ; //低温报警值
    @Value("${maxTemp}")
    private  Double maxTemp ;//高温报警值

    @Override
    public Result getPigpenByFarm(Integer farmId) {
        //--读取所有猪舍
        List<BasePigpenEntity> zsdsList = basePigpenRepo.getAllPigpen(farmId);
//        System.out.println("zsdsList.size>>"+zsdsList.size());
        if (zsdsList.size() == 0) {
            //返回出错
            return new Result(10001, "牧场id(" + farmId + ")中的猪舍为0", false);
        }
        List zsidList = new ArrayList();
        for (BasePigpenEntity zsdaEntity : zsdsList) {
            zsidList.add(zsdaEntity.getID());
        }
//        System.out.println("zsSb>>"+zsidList.toString());
        //--读取所有栏期
        List<BaseColumnPeriodEntity> lqdaEntityList = baseColumnPeriodRepo.getLqid(zsidList);
//        System.out.println("栏期length>>"+lqdaEntityList.size());
        if (lqdaEntityList.size() == 0) {
            //返回出错.
            return new Result(10002, "这个牧场(" + farmId + ")中的猪舍暂无相关任何栏期", false);
        }
        List lqidList = new ArrayList();
//        for (DaLqdaEntity lqdaEntity : lqdaEntityList) {
//            lqidList.add(lqdaEntity.getID());
//        }
//        System.out.println("lqidList>>"+lqidList.toString());
        JSONArray zsJa = new JSONArray();
        for (BasePigpenEntity zsdaEntity : zsdsList) {
            int zsid = zsdaEntity.getID();
            JSONObject zsJo = new JSONObject();
            zsJa.add(zsJo);
            zsJo.put("zsid", zsid);
            zsJo.put("zsmc", zsdaEntity.getZSMC());
            for (BaseColumnPeriodEntity lqdaEntity : lqdaEntityList) {
                if (lqdaEntity.getZSID() == zsid) {
                    zsJo.put("lqid", lqdaEntity.getID());
                    break;
                }
            }
        }
        return new Result(ResultCode.SUCCESS, zsJa);
    }

    @Override
    public Result getLastEnvData(Integer lqid) {
        String todayDate = new DateUtil().formatDate(new Date());
        System.out.println(" todayDate>>"+todayDate);
        System.out.println(" lqid>>"+lqid);
        JSONObject envJo = new JSONObject();
        envJo.put("lqid",lqid);
        //--读取最新氨气
        SjHkAq aqEntity = aqRepo.getLastAq(lqid, todayDate);
        System.out.println("aqEntity>>" + aqEntity);
        if (aqEntity != null) {
            envJo.put("ammonia", aqEntity.getDqaq());
        } else {
            envJo.put("ammonia", "");
        }
        //--读取最新湿度
        SjHkSd sdEntity = sdRepo.getLastSd(lqid, todayDate);
        if (sdEntity != null) {
            envJo.put("humidity", sdEntity.getDqsd());
        } else {
            envJo.put("humidity", "");
        }
        //--读取最新温度
        SjHkWd wdEntity = wdRepo.getLastWd(lqid, todayDate);
        if (wdEntity != null) {
            envJo.put("temp", wdEntity.getDqwd());
        } else {
            envJo.put("temp", "");
        }
        return new Result(ResultCode.SUCCESS, envJo);
    }


    @Autowired
    private  DeviceUpDataEntityRepo deviceUpDataEntityRepo;

    @Override
    public Result getAllFarm(){
        List endList  = new ArrayList();
        List<FarmSm> all = farmSmRepository.findAll();


        for (FarmSm farmSm : all) {
            Map map = new HashMap();
            String lqid = farmSm.getLqid();
            DeviceUpDataEntity byDeviceId = deviceUpDataEntityRepo.findByDeviceId(lqid);
            map.put("aq",0);
            map.put("name",farmSm.getName());
            map.put("lqid",byDeviceId.getDeviceId());
            map.put("sd",byDeviceId.getDataHumiConvert());
            map.put("wd",byDeviceId.getDataTempConvert());
            endList.add(map);
        }


        return new Result(ResultCode.SUCCESS,endList);
    }

    @Override
    public Result getAllBylqid(String lqid) {
         List endList = new ArrayList();


        String today= cn.hutool.core.date.DateUtil.today();
//        List<DeviceUpDataEntity> allByTimestampBetweenAndDeviceId = deviceUpDataEntityRepo.findAllByTimestampBetweenAndDeviceId(starTime, endTime, lqid);
        List<DeviceUpDataEntity> allByDeviceIdOrderByIdDesc = deviceUpDataEntityRepo.findAllByDeviceIdOrderByIdDesc(today,lqid);
        for (DeviceUpDataEntity deviceUpDataEntity : allByDeviceIdOrderByIdDesc) {
            Map map = new HashMap();
            map.put("time",deviceUpDataEntity.getTimestamp().substring(11));
            map.put("wd",deviceUpDataEntity.getDataTempConvert());
            map.put("sd",deviceUpDataEntity.getDataHumiConvert());
            map.put("aq",0);
            endList.add(map);
        }


        return new Result(ResultCode.SUCCESS,endList);
    }


    @Override
    public Result warningInfor() {
        List endList  = new ArrayList();
        List<DeviceUpDataEntity> allByTimestampBetween = deviceUpDataEntityRepo.findAllByTimestampBetween(minTemp, maxTemp, cn.hutool.core.date.DateUtil.today());
        for (DeviceUpDataEntity deviceUpDataEntity : allByTimestampBetween) {
            Map map  = new HashMap();
            map.put("farmName",farmSmRepository.findByLqid(deviceUpDataEntity.getDeviceId()).getName());
            map.put("time",deviceUpDataEntity.getTimestamp());
            String str  = "";
            if (deviceUpDataEntity.getDataTempConvert() < minTemp){
                str = str +"温度过低,温度:"+ deviceUpDataEntity.getDataTempConvert();
            }
            if (deviceUpDataEntity.getDataTempConvert() > maxTemp){
                str = str +"温度过高,温度:"+ deviceUpDataEntity.getDataTempConvert();
            }
            map.put("msg",str);
            endList.add(map);
        }

        return new Result(ResultCode.SUCCESS,endList) ;
    }


    @Override
    public Result findByZSID() {
        return null;
    }

  /*  @Override
    public Result getAllFarm() {


        List<FarmSm> all = farmSmRepository.findAll();

        String dateStr = "2021-03-14 00:00:00";
        String endDateStr ="2021-03-14 "+ (new Date()+"").substring(11,19);
        System.out.println(endDateStr);


        Date date = null;
        Date endDate = null;
        try {
            date = DateUtil.parseDateTime(dateStr);
            endDate = DateUtil.parseDateTime(endDateStr);
        } catch (ParseException e) {
            e.printStackTrace();
        }

        List endList = new ArrayList();

        for (FarmSm farmSm : all) {
            Map endMap = new HashMap();
            endMap.put("name",farmSm.getName());

            String lqid = farmSm.getLqid();
            endMap.put("lqid",farmSm.getLqid());

            List<SjHkAq> allByLqidAndScsjBetween = aqRepo.findAllByLqidAndScsjBetween(lqid, date, endDate);
            if ( allByLqidAndScsjBetween.size() >0){
                SjHkAq sjHkAq1 = allByLqidAndScsjBetween.get(allByLqidAndScsjBetween.size()-1);
                endMap.put("aq",sjHkAq1.getDqaq());
            }

            List<SjHkSd> allByLqidAndScsjBetween1 = sdRepo.findAllByLqidAndScsjBetween(lqid, date, endDate);
            if ( allByLqidAndScsjBetween1.size() >0){
                SjHkSd sjHkAq1 = allByLqidAndScsjBetween1.get(allByLqidAndScsjBetween1.size()-1);
                endMap.put("sd",sjHkAq1.getDqsd());
            }

            List<SjHkWd> allByLqidAndScsjBetween2 = wdRepo.findAllByLqidAndScsjBetween(lqid, date, endDate);
            if ( allByLqidAndScsjBetween2.size() >0){
                SjHkWd sjHkAq2 = allByLqidAndScsjBetween2.get(allByLqidAndScsjBetween2.size()-1);
                endMap.put("wd",sjHkAq2.getDqwd());
            }

            endList.add(endMap);

        }
        return new Result(ResultCode.SUCCESS,endList);
    }*/

   /* @Override
    public Result getAllBylqid(String lqid) {

        String dateStr = "2021-03-14 00:00:00";
        String endDateStr ="2021-03-14 "+ (new Date()+"").substring(11,19);
        System.out.println(endDateStr);


        Date date = null;
        Date endDate = null;
        try {
            date = DateUtil.parseDateTime(dateStr);
            endDate = DateUtil.parseDateTime(endDateStr);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        Map map =new HashMap();

        List aqList = new ArrayList();
        List<SjHkAq> allByLqidAndScsjBetween = aqRepo.findAllByLqidAndScsjBetween(lqid, date, endDate);
        for (SjHkAq sjHkAq : allByLqidAndScsjBetween) {
                Map map1 = new HashMap();
                map1.put("time",(sjHkAq.getScsj()+"").substring(11,19));
                map1.put("data",sjHkAq.getDqaq());
                 aqList.add(map1);
        }
        map.put("aq",aqList);


        List sdList = new ArrayList();
        List<SjHkSd> allByLqidAndScsjBetween1 = sdRepo.findAllByLqidAndScsjBetween(lqid, date, endDate);
        for (SjHkSd sjHkSd : allByLqidAndScsjBetween1) {
            Map map1 = new HashMap();
            map1.put("time",(sjHkSd.getScsj()+"").substring(11,19));
            map1.put("data",sjHkSd.getDqsd());
            sdList.add(map1);
        }
        map.put("sd",sdList);


        List wdList = new ArrayList();
        List<SjHkWd> allByLqidAndScsjBetween2 = wdRepo.findAllByLqidAndScsjBetween(lqid, date, endDate);
        for (SjHkWd sjHkWd : allByLqidAndScsjBetween2) {
            Map map1 = new HashMap();
            map1.put("time",(sjHkWd.getScsj()+"").substring(11,19));
            map1.put("data",sjHkWd.getDqwd());
            wdList.add(map1);
        }
        map.put("wd",wdList);

        return new Result(ResultCode.SUCCESS,map);
    }
*/

}
